@@ -27,13 +27,23 @@
 #include <QStandardPaths>
 #include <QDebug>
 
-Category::Category(QSet<QString>  pluginName, QObject* parent)
+Category::Category(QSet<QString> pluginName, QObject* parent)
         : QObject(parent)
         , m_iconString(QStringLiteral("applications-other"))
-        , m_showTechnical(false)
         , m_plugins(std::move(pluginName))
 {}
 
+Category::Category(const QString& name, const QString& iconName, const QVector<QPair<FilterType, QString> >& orFilters, const QSet<QString> &pluginName, const QVector<Category *>& subCategories, const QUrl& decoration, bool isAddons)
+    : QObject(nullptr)
+    , m_name(name)
+    , m_iconString(iconName)
+    , m_decoration(decoration)
+    , m_orFilters(orFilters)
+    , m_subCategories(subCategories)
+    , m_plugins(pluginName)
+    , m_isAddons(isAddons)
+{}
+
 Category::~Category() = default;
 
 void Category::parseData(const QString& path, const QDomNode& data)
@@ -63,8 +73,6 @@ void Category::parseData(const QString& path, const QDomNode& data)
             m_isAddons = true;
         } else if (tempElement.tagName() == QLatin1String("Icon") && tempElement.hasChildNodes()) {
             m_iconString = tempElement.text();
-        } else if (tempElement.tagName() == QLatin1String("ShowTechnical")) {
-            m_showTechnical = true;
         } else if (tempElement.tagName() == QLatin1String("Include")) { //previous muon format
             parseIncludes(tempElement);
         } else if (tempElement.tagName() == QLatin1String("Categories")) { //as provided by appstream
@@ -132,30 +140,28 @@ QVector<QPair<FilterType, QString> > Category::notFilters() const
     return m_notFilters;
 }
 
-bool Category::shouldShowTechnical() const
-{
-    return m_showTechnical;
-}
-
 QVector<Category *> Category::subCategories() const
 {
     return m_subCategories;
 }
 
+bool Category::categoryLessThan(Category *c1, const Category *c2)
+{
+    return (!c1->isAddons() && c2->isAddons()) || (c1->isAddons()==c2->isAddons() && QString::localeAwareCompare(c1->name(), c2->name()) < 0);
+}
+
 //TODO: maybe it would be interesting to apply some rules to a said backend...
 void Category::addSubcategory(QVector< Category* >& list, Category* newcat)
 {
     Q_FOREACH (Category* c, list) {
         if(c->name() == newcat->name()) {
             if(c->icon() != newcat->icon()
-                || c->shouldShowTechnical() != newcat->shouldShowTechnical()
                 || c->m_andFilters != newcat->m_andFilters
                 || c->m_isAddons != newcat->m_isAddons
             )
             {
                 qWarning() << "the following categories seem to be the same but they're not entirely"
                     << c->name() << newcat->name() << "--"
-                    << c->shouldShowTechnical() << newcat->shouldShowTechnical() << "--"
                     << c->andFilters() << newcat->andFilters() << "--"
                     << c->isAddons() << newcat->isAddons();
                 break;
@@ -172,6 +178,12 @@ void Category::addSubcategory(QVector< Category* >& list, Category* newcat)
             }
         }
     }
+    for(auto it = list.begin(), itEnd = list.end(); it!=itEnd; ++it) {
+        if (!categoryLessThan(*it, newcat)) {
+            list.insert(it, newcat);
+            return;
+        }
+    }
     list << newcat;
 }
 
@@ -210,6 +222,15 @@ QVariantList Category::subCategoriesVariant() const
     return ret;
 }
 
+bool Category::matchesCategoryName(const QString& name) const
+{
+    for(const auto &filter: m_orFilters) {
+        if (filter.first == CategoryFilter && filter.second == name)
+            return true;
+    }
+    return false;
+}
+
 bool Category::contains(Category* cat) const
 {
     const bool ret = cat == this || (cat && contains(qobject_cast<Category*>(cat->parent())));
