@@ -129,7 +129,7 @@ void ReviewsModel::restartFetching()
 
 void ReviewsModel::fetchMore(const QModelIndex& parent)
 {
-    if(!m_backend || !m_app || parent.isValid() || !m_canFetchMore)
+    if(!m_backend || !m_app || parent.isValid() || m_backend->isFetching() || !m_canFetchMore)
         return;
 
     m_lastPage++;
@@ -137,14 +137,14 @@ void ReviewsModel::fetchMore(const QModelIndex& parent)
 //     qDebug() << "fetching reviews... " << m_lastPage;
 }
 
-void ReviewsModel::addReviews(AbstractResource* app, const QVector<ReviewPtr>& reviews)
+void ReviewsModel::addReviews(AbstractResource* app, const QVector<ReviewPtr>& reviews, bool canFetchMore)
 {
     if(app!=m_app)
         return;
-    
-    m_canFetchMore=!reviews.isEmpty();
+
+    m_canFetchMore = canFetchMore;
 //     qDebug() << "reviews arrived..." << m_lastPage << reviews.size();
-    
+
     if(!reviews.isEmpty()) {
         beginInsertRows(QModelIndex(), rowCount(), rowCount()+reviews.size()-1);
         m_reviews += reviews;
