@@ -107,8 +107,18 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
 
     m_engine = new KNSCore::Engine(this);
     m_engine->init(m_name);
-    connect(m_engine, &KNSCore::Engine::signalError, this, [this](const QString &error) { qWarning() << "kns error" << objectName() << error; });
-    connect(m_engine, &KNSCore::Engine::signalEntriesLoaded, this, &KNSBackend::receivedEntries);
+    // Setting setFetching to false when we get an error ensures we don't end up in an eternally-fetching state
+    connect(m_engine, &KNSCore::Engine::signalError, this, [this](const QString &error) {
+        if(error == QLatin1Literal("All categories are missing")) {
+            markInvalid(error);
+        }
+        m_responsePending = false;
+        Q_EMIT searchFinished();
+        Q_EMIT availableForQueries();
+        this->setFetching(false);
+        qWarning() << "kns error" << objectName() << error;
+    });
+    connect(m_engine, &KNSCore::Engine::signalEntriesLoaded, this, &KNSBackend::receivedEntries, Qt::QueuedConnection);
     connect(m_engine, &KNSCore::Engine::signalEntryChanged, this, &KNSBackend::statusChanged);
     connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, this, &KNSBackend::statusChanged);
     m_page = -1;
@@ -187,11 +197,14 @@ void KNSBackend::receivedEntries(const KNSCore::EntryInternal::List& entries)
         setFetching(false);
         return;
     }
-//     qDebug() << "received" << this << m_page << m_resourcesByName.count();
+//     qDebug() << "received" << objectName() << this << m_page << m_resourcesByName.count();
     if (!m_responsePending) {
         ++m_page;
-        m_engine->requestData(m_page, 100);
+        // We _have_ to set this first. If we do not, we may run into a situation where the
+        // data request will conclude immediately, causing m_responsePending to remain true
+        // for perpetuity as the slots will be called before the function returns.
         m_responsePending = true;
+        m_engine->requestData(m_page, 100);
     } else {
         Q_EMIT availableForQueries();
     }
@@ -315,11 +328,11 @@ ResultsStream * KNSBackend::searchStream(const QString &searchText)
         m_responsePending = true;
         m_page = 0;
         connect(this, &KNSBackend::receivedResources, stream, &ResultsStream::resourcesFound);
-        connect(this, &KNSBackend::searchFinished, stream, &ResultsStream::deleteLater);
-        connect(this, &KNSBackend::startingSearch, stream, &ResultsStream::deleteLater);
+        connect(this, &KNSBackend::searchFinished, stream, &ResultsStream::finish);
+        connect(this, &KNSBackend::startingSearch, stream, &ResultsStream::finish);
     };
     if (m_responsePending) {
-        connect(this, &KNSBackend::availableForQueries, stream, start);
+        connect(this, &KNSBackend::availableForQueries, stream, start, Qt::QueuedConnection);
     } else {
         start();
     }
@@ -344,14 +357,14 @@ ResultsStream * KNSBackend::findResourceByPackageName(const QUrl& search)
     auto start = [this, entryid, stream]() {
         m_responsePending = true;
         m_engine->fetchEntryById(entryid);
-        connect(m_engine, &KNSCore::Engine::signalError, stream, &QObject::deleteLater);
+        connect(m_engine, &KNSCore::Engine::signalError, stream, &ResultsStream::finish);
         connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, stream, [this, stream, entryid](const KNSCore::EntryInternal &entry) {
             if (entry.uniqueId() == entryid) {
                 stream->resourcesFound({resourceForEntry(entry)});
             }
             m_responsePending = false;
             QTimer::singleShot(0, this, &KNSBackend::availableForQueries);
-            stream->deleteLater();
+            stream->finish();
         });
     };
     if (m_responsePending) {
