@@ -26,11 +26,11 @@
 #include "AppPackageKitResource.h"
 #include "PKTransaction.h"
 #include "LocalFilePKResource.h"
-#include "AppstreamReviews.h"
 #include <resources/AbstractResource.h>
 #include <resources/StandardBackendUpdater.h>
 #include <resources/SourcesModel.h>
 #include <Transaction/TransactionModel.h>
+#include <ReviewsBackend/OdrsReviewsBackend.h>
 
 #include <QProcess>
 #include <QStringList>
@@ -45,6 +45,7 @@
 #include <KDesktopFile>
 #include <KLocalizedString>
 #include <QAction>
+#include <QMimeDatabase>
 
 #include "utils.h"
 #include "config-paths.h"
@@ -61,7 +62,7 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
     , m_updater(new PackageKitUpdater(this))
     , m_refresher(nullptr)
     , m_isFetching(0)
-    , m_reviews(new AppstreamReviews(this))
+    , m_reviews(new OdrsReviewsBackend(this))
 {
     bool b = m_appdata.load();
     reloadPackageList();
@@ -106,7 +107,7 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
 
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::updatesChanged, this, &PackageKitBackend::fetchUpdates);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::isRunningChanged, this, &PackageKitBackend::checkDaemonRunning);
-    connect(m_reviews, &AppstreamReviews::ratingsReady, this, &AbstractResourcesBackend::emitRatingsReady);
+    connect(m_reviews, &OdrsReviewsBackend::ratingsReady, this, &AbstractResourcesBackend::emitRatingsReady);
 
     SourcesModel::global()->addSourcesBackend(new PackageKitSourcesBackend(this));
 }
@@ -417,8 +418,8 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
                 const auto res = resourcesByPackageNames<QVector<AbstractResource*>>({PackageKit::Daemon::packageName(packageId.toString())});
                 stream->resourcesFound(kFilter<QVector<AbstractResource*>>(res, [ids](AbstractResource* res){ return !ids.contains(res->appstreamId()); }));
             }
-            stream->deleteLater();
-        });
+            stream->finish();
+        }, Qt::QueuedConnection);
         return stream;
     }
 }
@@ -582,7 +583,16 @@ AbstractReviewsBackend* PackageKitBackend::reviewsBackend() const
 
 AbstractResource * PackageKitBackend::resourceForFile(const QUrl& file)
 {
-    return new LocalFilePKResource(file, this);
+    QMimeDatabase db;
+    const auto mime = db.mimeTypeForUrl(file);
+    if (    mime.inherits(QLatin1String("application/vnd.debian.binary-package"))
+         || mime.inherits(QLatin1String("application/x-rpm"))
+         || mime.inherits(QLatin1String("application/x-tar"))
+         || mime.inherits(QLatin1String("application/x-xz-compressed-tar"))
+    ) {
+        return new LocalFilePKResource(file, this);
+    }
+    return nullptr;
 }
 
 
