@@ -24,28 +24,48 @@
 #include <Category/CategoryModel.h>
 #include <KLocalizedString>
 #include <KFormat>
+#include <KShell>
 #include <QList>
+#include <QProcess>
 #include <QDebug>
 
 AbstractResource::AbstractResource(AbstractResourcesBackend* parent)
     : QObject(parent)
 {
+    connect(this, &AbstractResource::stateChanged, this, &AbstractResource::sizeChanged);
     connect(this, &AbstractResource::stateChanged, this, &AbstractResource::reportNewState);
 }
 
 bool AbstractResource::canExecute() const
 {
-    return false;
+    return !executables().isEmpty();
 }
 
 void AbstractResource::invokeApplication() const
-{}
+{
+    QStringList exes = executables();
+    if(!exes.isEmpty()) {
+        const QString exe = exes.at(0);
+        auto args = KShell::splitArgs(exe);
+        QProcess::startDetached(args.takeFirst(), args);
+    }
+}
 
 bool AbstractResource::isTechnical() const
 {
     return false;
 }
 
+void AbstractResource::addMetadata(const QString &key, const QVariant &value)
+{
+    m_metadata.insert(key, value);
+}
+
+QVariant AbstractResource::getMetadata(const QString &key)
+{
+    return m_metadata.value(key);
+}
+
 bool AbstractResource::canUpgrade()
 {
     return state() == Upgradeable;
